#
# spec file for package emacs-auctex
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           emacs-auctex
BuildRequires:  emacs-x11
BuildRequires:  ghostscript_any
BuildRequires:  texlive
BuildRequires:  texlive-latex
Obsoletes:      ge_auc
Provides:       auc-tex
Provides:       auctex
Provides:       ge_auc
Requires:       emacs
Requires:       texlive-latex
Requires:       texlive-tools
%if %suse_version > 1220
BuildRequires:  makeinfo
BuildRequires:  texinfo
BuildRequires:  texlive-collection-latexextra
BuildRequires:  texlive-tex
BuildRequires:  texlive-texinfo
%endif
Version:        12.1
Release:        lp151.2.67
Summary:        AUC TeX: An Emacs Extension
License:        GPL-2.0-or-later
Group:          Productivity/Editors/Emacs
Source:         http://ftp.gnu.org/pub/gnu/auctex/auctex-%{version}.tar.gz
Url:            http://www.gnu.org/software/auctex
# Allows to select printer instance
# PATCH-FEATURE-UPSTREAM dvips.patch
Patch0:         dvips.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
These macros make it easier for you to write TeX documents with GNU
Emacs.	Documentation can be found under:

/usr/share/doc/packages/emacs-auctex/

and in the dvi files math-ref.dvi and tex-ref.dvi (reference cards) and
in the info file auctex in emacs info-mode.

AuC TeX is integrated in XEmacs 19.15 and higher, so these packages may
not be installed concurrently.	Note that the binary formats of the
byte-compiled lisp files of the two emacs editors are incompatible, so
you cannot use this package for XEmacs.

%define _sitedir %{_datadir}/emacs/site-lisp
%define _aucdir  %{_sitedir}/auctex

%prep
%setup -n auctex-%{version}
%patch0

%build
    unset ${!LC_*}
    LANG=en_US.UTF-8
    export LANG
    rm -rf /tmp/auctex
    mkdir  /tmp/auctex
    mkdir -p /tmp/auctex/doc/preview
    mkdir -p /tmp/auctex/latex/preview
    %configure \
	--docdir=%{_defaultdocdir}/%name	\
	--with-emacs				\
	--with-lispdir=%{_sitedir}		\
	--with-auto-dir=%{_aucdir}/auto		\
	--with-texmf-dir=%{_datadir}/texmf	\
	--with-doc-dir=/tmp/auctex/doc/preview	\
	--with-tex-dir=/tmp/auctex/latex/preview
    find , -name '*.elc' | xargs -r rm -f
    make %{?_smp_mflags}
    make -C doc clean
    make -C doc %{?_smp_mflags}
    make -C doc extradist
    rm -rf /tmp/auctex

%install
    export LC_CTYPE=ISO-8859-1
    mkdir -p %{buildroot}%{_sitedir}/site-start.d
    make install DESTDIR=%{buildroot}
    rm -rf %{buildroot}%{_aucdir}/auto
    pushd %{buildroot}%{_aucdir}/
	emacs --no-site -batch -L %{buildroot}%{_sitedir}/auctex 		\
	    --eval '(setq TeX-lisp-directory "%{buildroot}%{_aucdir}")'		\
	    --eval '(setq TeX-auto-global "%{buildroot}%{_aucdir}/auto")'	\
	    -l %{buildroot}%{_sitedir}/tex-site.el -f TeX-auto-generate-global
    popd
    touch %{buildroot}%{_aucdir}/auto/.nosearch
    find %{buildroot}%{_aucdir}/auto/ -name '*.elc' | xargs -r rm -f
    cat <<-EOF > %{buildroot}%{_sitedir}/suse-start-auctex.el
	;;; suse-start-auctex.el
	;;
	;; This is used for starting up AUCTeX
	;; See (info "(auctex)Introduction") on how to disable AUCTeX.
	;;
	(load "auctex.el" nil t t)
	EOF
    cat <<-EOF > %{buildroot}%{_sitedir}/suse-start-preview-latex.el
	;;; suse-start-preview-latex.el
	;;
	;; This is used for starting up preview-latex of AUCTeX
	;; See (info "(auctex)Introduction") on how to disable AUCTeX.
	;;
	(load "preview-latex.el" nil t t)
	EOF
    for el in auctex.el preview-latex.el
    do
	test -e %{buildroot}%{_sitedir}/$el || continue
	mv %{buildroot}%{_sitedir}/$el %{buildroot}%{_sitedir}/site-start.d/
    done
    #
    # Preview is part of te_latex
    #
    rm -rf %{buildroot}/tmp/auctex
%define info_files auctex.info preview-latex.info

%post
for f in %info_files; do
 %install_info --info-dir=%{_infodir} %{_infodir}/$f.gz
done

%postun
for f in %info_files; do
  %install_info_delete --info-dir=%{_infodir} %{_infodir}/$f.gz
done

%files
%defattr(-, root, root)
%doc README COPYING doc/*.pdf CHANGES
%dir %{_sitedir}/
%dir %{_aucdir}/
%dir %{_aucdir}/auto/
%dir %{_aucdir}/images/
%dir %{_aucdir}/style/
%doc %{_infodir}/*.info*.gz
%{_aucdir}/*.el
%{_aucdir}/*.elc
%{_aucdir}/auto/*.el
%{_aucdir}/images/*.xpm
%{_aucdir}/style/*.el
%{_aucdir}/style/*.elc
%{_aucdir}/auto/.nosearch
%{_aucdir}/style/.nosearch
%config %{_sitedir}/suse-start*.el
%config %{_sitedir}/tex-site.el
%config %{_sitedir}/site-start.d/auctex.el
%config %{_sitedir}/site-start.d/preview-latex.el

%changelog
* Wed Apr 18 2018 werner@suse.de
- Update to 12.1 due bug boo#1088548
  * AUCTeX now requires GNU Emacs 24 or higher.  Support for XEmacs has
  * Besides the change in the supported version of Emacs, there has
    been no functional change in this release, which is equivalent to
    version 11.92.
  * preview-latex is compatible with Ghostscript 9.22 where the
    operator '.runandhide' is removed.  All occurrences of
    '.runandhide' in preview-latex are replaced by alternative code
    making it work with Ghostscript 9.22 again.
  * AUCTeX has a new customize option
    'TeX-math-input-method-off-regexp'.  When you begin to input a math
    formula, the current input method is turned off if its name matches
    this regular expression.
  * The window system focus is pulled back to Emacs when viewing with
    evince-compatible viewers if a new customize option
    'TeX-view-evince-keep-focus' is non-nil.
  * The usual dose of bug fixes was administered.
  * Now AUCTeX has a logo.  The LaTeX code to create it is available in
    the 'etc/' directory of the package.
  * Add support for 'upmendex', an extension of 'makeindex' capable of
    sorting indexes by unicode based ICU.
  * Fix preview-latex to interact correctly with Japanese LaTeX.  The
    parsing routine was made robust not to be confused by the 7-bit
    encoding of Japanese text and the necessary option to LaTeX command
    is kept even when preamble caching is enabled.
  * The new "Glossaries" entry in 'TeX-command-list' runs the command
    'makeglossaries'.
  * Fontification of control symbols has been improved.  Characters
    defined in 'font-latex-match-simple-exclude-list' do not receive
    any fontification.  In DocTeX mode, the character '_' is removed
    from 'font-latex-match-simple-exclude-list' in order to fontify
    macros like '\__module_foo:nnn' correctly.
  * Fontification of math environments has been improved.  Optional
    and/or mandatory argument(s) to environments are not fontified.
  * 'preview.sty' loads 'luatex85.sty' if possible and should be
    compatible with newer luaTeX versions.
  * AUCTeX has a new customize option 'TeX-ispell-verb-delimiters'.
    This string contains usual characters used as delimiters for
    in-line verbatim macros like '\verb'.  Text between delimiters
    after an in-line verbatim macro will be skipped during spell
    checking.
  * Fontification of in-line verbatim macros has been improved.
    'font-latex.el' recognizes an optional or a mandatory argument for
    macros like '\Verb' from 'fancyvrb.sty', '\mint' and '\mintinline'
    from 'minted.sty' and fontifies verbatim content correctly.
  * AUCTeX can put and parse labels in optional argument of
    environments.  Inserting labels is done by new function
    'LaTeX-env-label-as-keyval'.  A new customize option
    'LaTeX-listing-label' is available as prefix to labels in code
    typesetting environments, e.g.  'lstlisting' environment provided
    by 'listings' package.  'LaTeX-listing-label' defaults to 'lst:'.
    Parsing of labels for later referencing relies on two requirements:
    1. Label should come as last key-value argument, and
    2. label must be enclosed in braces, e.g.
    \begin{lstlisting}[caption=Some Caption,label={lst:foo}]
    ...
    \end{lstlisting}
  * The function 'LaTeX-label' now takes a second optional argument
    'NO-INSERT'.  When non-'nil', 'LaTeX-label' reads a label and
    returns it as a string.  This argument is also passed to any
    function bound to 'LaTeX-label-function' (see next item).
  * *Incompatible change:* The signature for the function passed with
    the customize option 'LaTeX-label-function' has changed.  The
    function bound to this variable is now expected to take an optional
    second argument 'NO-INSERT'.  When this argument is non-'nil', the
    function should read and only return a label as a string; insertion
    is done by another function.
  * Directory local variables were ineffective for
    'japanese-latex-mode' and 'japanese-plain-tex-mode'.  This bug was
    fixed.  (This was actually done in AUCTeX 11.90, but not
    advertised)
  * The output of Japanese text from Japanese TeX engines is decoded
    correctly for most cases, according to the encoding of the TeX
    documents and the locale.  The difference between MS Windows, macOS
    and unix-like OS is taken into account.  (This was actually done in
    AUCTeX 11.90, but not advertised)
  * Quite a few new LaTeX packages are supported.
  * As usual, many bugs were fixed.
* Thu Jun 29 2017 werner@suse.de
- Update to 11.90
  * In addition to the completion performed by 'TeX-complete-symbol',
    AUCTeX now also supports the new Emacs standard completion-at-point
    facility (see the Emacs command 'completion-at-point').  This also
    means that modern completion UIs like company-mode work out of the
    box in TeX and LaTeX buffers.
  * Completion is now aware of being inside a math environment and then
    completes math macros.
  * AUCTeX is able to display several levels of super- and subscripts,
    each one raised above and a bit smaller than its basis.  For this
    feature, have a look at the customize options
    'font-latex-fontify-script' (especially the new values
    'multi-level' and 'invisible') and
    'font-latex-fontify-script-max-level'.  Also, the script characters
    '^' and '_' are also fontified with a special face named
    'font-latex-script-char-face'.
  * Parsing of format specification in various tabular environments has
    been improved.  The function 'LaTeX-insert-item' ('C-c <LFD>')
    inserts suitable number of ampersands for '*{num}{cols}'
    constructs.  Style files for LaTeX packages 'tabularx', 'tabulary',
    'longtable', 'dcolumn' and 'siunitx' are adapted to take advantage
    of this improvement.
  * AUCTeX has a new Ispell dictionary 'tex-ispell.el' for macros and
    environments which will be skipped during spell checking.  The
    activiation of this feature is controlled by a new customize option
    'TeX-ispell-extend-skip-list', which is set to 't' and activated by
    default.
  * AUCTeX has a new customize option 'TeX-raise-frame-function' that
    is currently only used by Evince and Atril inverse search to raise
    the Emacs frame.
  * When inserting a new float, AUCTeX will now prompt for a
    short-caption if the length of the caption provided is greater than
    a certain size.  This size is controlled via a new user option
    'LaTeX-short-caption-prompt-length'.
  * Parsing of the compilation log has been reworked.  You should
    encounter fewer mistaken files while navigating through errors and
    warnings.
  * Two new user options, 'TeX-ignore-warnings' and
    'TeX-suppress-ignored-warnings', allow ignoring certain warnings
    after compilation of the document.
  * A new option, 'TeX-PDF-from-DVI', controls if and how to produce a
    PDF file by converting a DVI file.  This supersedes
    'TeX-PDF-via-dvips-ps2pdf' which is still recognized but marked as
    obsolete and may be removed in future releases.
  * Support for a number of external viewers has been added
  * A new function, 'TeX-documentation-texdoc', for reading
    documentation with 'texdoc' has been added.  'TeX-doc' is still
    available but now 'C-c ?' runs 'TeX-documentation-texdoc'.
  * AUCTeX has a new custom option
    'LaTeX-reftex-cite-format-auto-activate' which controls the
    automatic activation of citation formats provided by RefTeX when a
    style file is loaded and RefTeX is enabled.  Currently,
    'biblatex.el', 'harvard.el', 'jurabib.el' and 'natbib.el' use this
    feature.  If you have customized 'reftex-cite-format' and want to
    use your settings, you should set this variable to 'nil'.
  * AUCTeX now has limited support for the TikZ package.  For the
    moment, this includes some basic support for prompting the user of
    arguments to the '\draw' macro.
  * The style 'graphicx.el' went through a bigger overhaul.  The
    optional argument of command '\includegraphics' now supports
    key-val query; keys can independently be chosen anytime by pressing
    the <,> key.  As a side effect, the variable
    'LaTeX-includegraphics-options-alist' is now no-op and is removed
    from 'tex-style.el'.  You can safely remove any customization of it
    from your init file.  The mandatory argument of '\includegraphics'
    knows about image file extensions supported by the used engine and
    offers them for inclusion.
  * Support for other LaTeX packages was improved, and style files for
    several new packages were added.
  * Many bugs were crushed along the way.
- Remove patch 0001-Fix_bug_in_subfigure_style_filee.patch as now upstream
* Tue Sep 20 2016 werner@suse.de
- Add patch 0001-Fix_bug_in_subfigure_style_filee.patch
  to fix build with GNU Emacs 25.1
* Fri Nov 13 2015 auxsvr@gmail.com
- Remove auctex-11.86-dinbrief.dif, as it's been merged upstream, and
  everything in auctex-11.87.dif except for the dvips part (now in
  dvips.patch).
- Update to 18.89.
  * You can now run all commands needed to compile a document and then
    open the viewer with a single command: 'TeX-command-run-all', bound
    to 'C-c C-a'.
  * Commands such as LaTeX and View can now be executed conveniently on
    the current section (or part, chapter, subsection, etc).  See
    'LaTeX-command-section' and 'LaTeX-command-section-change-level'.
  * Forward and backward search with Evince now also work when only a
    region of the document is compiled/viewed.
  * To open the PDF output file you can now use also PDF Tools, a
    document viewer for Emacs.  With it, as a plus, forward and
    backward search is accurate at word level.
  * With new option 'TeX-PDF-via-dvips-ps2pdf' it is possible to
    compile a document to DVI and then convert it to PDF using
    'dvips'-'ps2pdf' before viewing it.
  * New option 'TeX-file-line-error' allows to select file:line:error
    style for error messages.
  * Indent '\[...\]' math mode as a regular environment by default.
  * Now AUCTeX suggests to run 'makeindex' when appropriate.
  * 'TeX-view-program-list' can contain, as third optional element of
    each item, the name of the executable(s) needed to open the viewer.
  * 'TeX-expand-list' variable has been split into 'TeX-expand-list'
    and 'TeX-expand-list-builtin'.  Only the former is intended to be
    customized by the user, the latter contains built-in expanders.
    You might want to keep in 'TeX-expand-list' only new expansion
    strings.
  * When new option 'TeX-check-engine' is non-nil, before running LaTeX
    commands AUCTeX will check whether the correct engine has been set,
    based upon known restrictions posed by LaTeX packages.
  * Basic support to ConTeXt Mark IV has been added.  Users can now
    select the Mark version to be used with new option
    'ConTeXt-Mark-version', and AUCTeX is able to catch error messages
    in the output log of a Mark IV document.
* Sun Sep 13 2015 auxsvr@gmail.com
- Update to 11.88
  * 'TeX-PDF-mode' is now enabled.
  * 'biblatex' support was greatly expanded.  If parsing is enabled, AUCTeX
    looks at 'backend' option to decide whether to use Biber or BibTeX. The
    'LaTeX-biblatex-use-Biber' variable was changed to be file local only
    and is no more customizable.by default.
  * Now you can insert '$...$' or '\(...\)' by typing a single '$'.  To do
    this, customize the new option 'TeX-electric-math'.
    'TeX-math-close-double-dollar' was removed.
  * Brace pairing feature was enhanced in LaTeX documents.  Support for
    '\bigl', '\Bigl', '\biggl' and '\Biggl', the same as the one for
    '\left', was added to 'TeX-insert-macro'.  For example, 'C-c <RET> bigl
    <RET> ( <RET>' inserts '\bigl(\bigr)'.
  * You can insert brace pair '()', '{}' and '[]' by typing a single left
    brace if the new user option 'LaTeX-electric-left-right-brace' is
    enabled.
* Tue Oct  7 2014 crrodriguez@opensuse.org
- No shared libraries are needed for build, this is a noarch
  package.
* Wed Sep 25 2013 werner@suse.de
- Make it build again as we have now a site-start.d below site-lisp
* Fri Jun  7 2013 werner@suse.de
- Use latest upstream update of dinbrief.el
* Thu Jun  6 2013 werner@suse.de
- Update to auctex 11.87
  * Includes the preview fix for ghostscript
  * Includes the changes for font-late.elc
- Remove auctex-11.86-font-latex.5.194.patch
* Thu Jun  6 2013 werner@suse.de
- Add patch auctex-11.86-font-latex.5.194.patch from upstream to
  make GNU emacs 24.3 silent about font-late.elc (reported by
  Johannes Roth)
* Fri Feb 22 2013 werner@suse.de
- Make dinbrief work again
* Mon Jul 23 2012 werner@suse.de
- Use texlive-texinfo for build and add also all LaTeX styles to
  be scanned during AucTeX build.
- Use texinfo *and* makeinfo for build as both are required
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Oct 13 2010 werner@suse.de
- Allow also to read PDF file its self to be able to generate the
  descriptions of those file (based on patch of Dieter Jurzitza)
* Wed Aug 11 2010 werner@suse.de
- Make fix for bnc#623719 more flexible
* Sun Jul 25 2010 aj@suse.de
- Package all info files.
* Wed Jul 21 2010 werner@suse.de
- Update to auctex 11.86
  * Parsing of LaTeX output was improved.  It is now less likely that
    AUCTeX opens a non-existent file upon calling `TeX-next-error'; a
    problem for example encountered when using MiKTeX 2.8.  In addition
    quoted file names as emitted by MiKTeX are now supported.
  * A new framework for the definition and selection of viewers was
    implemented.  If you have customizations regarding viewers you
    will have to redo them in this new framework or reenable the old
    one.  See the section on viewers in the manual for details.
  * Comprehensive editing support for PSTricks was added.
  * Support for various LaTeX packages was added, e.g. `tabularx',
    `CJK', and `hyperref'.
  * An easy way to switch between TeX engines (PDFTeX, LuaTeX, XeTeX,
    Omega) was added.
  * Support for SyncTeX was added.  This involves the command line
    options for LaTeX and the viewer.
  * Folding can now be customized to use macro arguments as replacement
    text.
  * `preview.sty' now works with XeTeX.
  * A lot of smaller and larger bugs have been squashed.
* Wed Jul 21 2010 werner@suse.de
- Fix the usage of ghostscript for preview mode also switch over to
  faster dvipng mode which is much faster than ghostscript (bnc#623719)
* Mon Mar 17 2008 werner@suse.de
- Use texlive-tools instead of lacheck
* Tue Mar 11 2008 werner@suse.de
- Avoid overlong file lists use find and xargs instead
* Mon Mar 10 2008 werner@suse.de
- Make it work with texlive and texlive-latex
- Update to auctec 11.85
  + News in 11.85
  * Font locking has been improved significantly.
  * The license was updated to GPLv3.
  * Support for the nomencl, flashcards and comment LaTeX packages
    as well as the Icelandic language option of babel were added.
  * Support for folding of math macros was added.
  * Lots of minor bugs in features and documentation fixed.
  + News in 11.84
  * AUCTeX has been changed in order to accommodate file names
    containing spaces.
  * Support for folding of comments was added.
  * The TeX tool bar is now available and enabled by default in
    plain TeX mode.
  * Bug fix in the display of math subscripts and superscripts.
  * Bug fix `TeX-doc' for Emacs 21.
  * There has been quite a number of other bug fixes to various
    features and documentation across the board.
* Sun Apr 29 2007 aj@suse.de
- Fix Requires for texlive.
* Fri Apr 27 2007 werner@suse.de
- Make it build with texlive
* Fri Mar  2 2007 werner@suse.de
- No binary anymore is no architecture
* Thu Jun 29 2006 werner@suse.de
- Update to 11.83
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 werner@suse.de
- Update to 11.55
- Use newer dinbrief.el
- Build as non root user
* Tue Sep 21 2004 werner@suse.de
- encl, cc ... should be included within letter environment
* Fri Jan  9 2004 werner@suse.de
- Update to 11.14
* Tue Jul  2 2002 werner@suse.de
- Update to auc-tex 11.11 (bug #16605)
* Fri Feb 22 2002 werner@suse.de
- Make conditionals in font-lock work with emacs 21.1
* Sat Feb  9 2002 ro@suse.de
- removed te_fr from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Nov  8 2001 werner@suse.de
- Add all libs reqired by emacs to neededforbuild
* Fri Mar 16 2001 werner@suse.de
- Mark tex-site.el as config file
* Tue Mar 13 2001 ro@suse.de
- added emacs-x11 to neededforbuild
* Wed Mar  7 2001 werner@suse.de
- Rename package to emacs-auctex
* Fri Nov 17 2000 ro@suse.de
- ge_exec -> emacs
* Tue Jun  6 2000 ro@suse.de
- doc relocation
* Fri Feb 25 2000 werner@suse.de
- Change dvips print command to be able to avoid config.lp
  within teTeX package
* Thu Feb 24 2000 werner@suse.de
- Make it work for all teTeX versions
  - /usr/info -> /usr/share/info
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 13 1999 werner@suse.de
- Make dinbrief.sty comaptible to xemacs
* Thu Jul  8 1999 werner@suse.de
- New version 9.9p
  - A few changes to my dinbrief.sty
* Thu Apr 15 1999 werner@suse.de
- added export LC_CTYPE=ISO-8859-1 to install section
* Wed Nov 18 1998 werner@suse.de
- Change file list because of the new tetex version
* Mon Jul 27 1998 bs@suse.de
- added export LC_CTYPE=ISO-8859-1 to build section - emacs needs it.
* Fri Jul 10 1998 bs@suse.de
- added xaw3d to neededforbuild (ge_exec needs it)
* Mon Jun  2 1997 werner@suse.de
- removed /usr/info/latex*.gz ... because it's included in tetex
* Wed May 28 1997 werner@suse.de
- New version 9.7p
  - Skip X-emacs: xemacs-19.15 has an integrated
  auctex version 9.7l
  - Added ltx-help.el, latex(2e).info due
  the auctex-9.7p does not has it anymore
* Thu Jan  2 1997 werner@suse.de
- auctex: Version 9.5a für GNU-emacs und X-emacs
